<?php
/**
 * Fix stuff from third parties
 *
 * @since 1.1.0
 */
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


/**
 * Remove picu collections from Yoast xml sitemaps
 *
 * @since 0.9.4
 */
function picu_remove_from_wpseo_sitemap( $exclude = false, $post_type ) {

	if ( 'picu_collection' == $post_type ) {
		return true;

	}
	return false;
}

add_filter( 'wpseo_sitemap_exclude_post_type', 'picu_remove_from_wpseo_sitemap', 10, 2 );


/**
 * Remove picu collections from Yoast xml sitemap options
 *
 * @since 1.1.0
 */
function picu_remove_from_wpseo_sitemap_options( $post_types ) {

	if ( isset( $post_types['picu_collection'] ) ) {
		unset( $post_types['picu_collection'] );
	}

	return $post_types;
}

add_filter( 'wpseo_sitemaps_supported_post_types', 'picu_remove_from_wpseo_sitemap_options', 10, 2 );


/**
 * Remove picu images from attachment sitemap
 *
 * @package picu
 * @since 1.1.0
 */
function picu_remove_attachments_from_yoast_sitemap( $output, $url ) {

	if ( isset( $url['images'][0]['src'] ) AND strpos( $url['images'][0]['src'], '/picu/' ) ) {
		return '';
	}
	else {
		return $output;
	}

}

add_filter( 'wpseo_sitemap_url', 'picu_remove_attachments_from_yoast_sitemap', 10, 2 );


/**
 * Remove Yoast meta box from picu collections
 *
 * @since 1.1.0
 */
function picu_remove_yoast_metabox() {
	 remove_meta_box( 'wpseo_meta', 'picu_collection', 'normal' );
}

add_action( 'add_meta_boxes', 'picu_remove_yoast_metabox', 99 );


/**
 * Remove Yoast collumns on collection overview screen
 *
 * @since 1.1.0
 */
function picu_remove_yoast_columns( $columns ) {

	unset( $columns['wpseo-score'] );
	unset( $columns['wpseo-title'] );
	unset( $columns['wpseo-metadesc'] );
	unset( $columns['wpseo-focuskw'] );
	unset( $columns['wpseo-score-readability'] );

	return $columns;
}

add_filter( 'manage_edit-picu_collection_columns', 'picu_remove_yoast_columns' );


/**
 * Remove picu collections from sitemaps created with the SEO Framework plugin
 *
 * @since 1.3.0
 */
function picu_remove_collections_from_seo_framework_sitemap() {
	return array( 'picu_collection' );
}

add_filter( 'the_seo_framework_sitemap_exclude_cpt', 'picu_remove_collections_from_seo_framework_sitemap' );


/**
 * Remove the SEO Framework meta box from picu collections
 *
 * @since 1.3.0
 */
function picu_remove_seo_framework_meta_box() {
	$current_screen = get_current_screen();

	if ( $current_screen->id == 'picu_collection' ) {
		add_filter( 'the_seo_framework_seobox_output', '__return_false' );
	}
}

add_action( 'current_screen', 'picu_remove_seo_framework_meta_box' );


// Enable for testing purposes only!
// add_filter('wpseo_enable_xml_sitemap_transient_caching', '__return_false');

/**
 * Disable code injection by NextGen Gallery
 *
 * @since 1.0.4
 */
function picu_disable_ngg_resource_manager() {
	global $post;

	if ( $post->post_type == 'picu_collection' ) {
		return false;
	}
}

add_filter( 'run_ngg_resource_manager', 'picu_disable_ngg_resource_manager' );



/**
 * Prevent Autoptimize from "optimizing" aka breaking stuff
 *
 * @since 1.3.2
 */
function picu_no_autoptimize() {
	global $post;

	if ( $post->post_type == 'picu_collection' ) {
		return true;
	}

	return false;
}

add_filter( 'autoptimize_filter_noptimize', 'picu_no_autoptimize' );


/**
 * Deactivate Real Media Library for picu collections
 *
 * @since 1.3.5
 */
function picu_deactivate_real_media_library( $active ) {

	global $post;

	if ( isset( $post->post_type ) AND $post->post_type == 'picu_collection' ) {
		$active = false;
	}

	return $active;

}

add_filter( 'RML/Active', 'picu_deactivate_real_media_library' );


/**
 * Do not use Jetpacks photon for picu images
 *
 * @since 1.4.5
 */
function picu_no_photon() {
	if ( get_post_type() == 'picu_collection' ) {
		add_filter( 'jetpack_photon_skip_image', '__return_true' );
	}
}
 
add_action( 'wp', 'picu_no_photon' );