<?php
/**
 * Plugin Name: picu
 * Plugin URI: https://picu.io/
 * Description: Send a collection of photographs to your client for approval.
 * Version: 1.4.8
 * Author: Haptiq
 * Author URI: https://picu.io/
 * License: GNU General Public License 2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: picu
 * Domain Path: /languages
 */
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


/**
 * Include functions for picu
 *
 * @package picu
 * @since 0.2.0
 */

if ( ! function_exists( 'picu_setup' ) ) {

	function picu_setup() {

		// Define plugin version
		define( 'PICU_VERSION', '1.4.8' );

		// Define path for this plugin
		define( 'PICU_PATH', plugin_dir_path(__FILE__) );

		// Define URL for this plugin
		define( 'PICU_URL', plugin_dir_url(__FILE__) );

		// Define picu upload dir
		$upload_dir = wp_upload_dir();
		define( 'PICU_UPLOAD_DIR', $upload_dir['basedir'] . '/picu' );

		// Include functions to render add-ons page
		require PICU_PATH . 'backend/includes/picu-addons-page.php';

		// Include functions to render admin menu and settings page
		require PICU_PATH . 'backend/includes/picu-settings.php';

		// Include function for registering custom post type collection
		require PICU_PATH . 'backend/includes/picu-cpt-collection.php';

		// Include welcome screen
		require PICU_PATH . 'backend/includes/picu-welcome-screen.php';

		// Include functions for admin notices and error messages
		require PICU_PATH . 'backend/includes/picu-admin-notices.php';

		// Include custom metabox and our custom edit screen
		require PICU_PATH . 'backend/includes/picu-edit-collection.php';

		// Picu media handling
		require PICU_PATH . 'backend/includes/picu-media.php';

		// Everything that doesn't fit anywhere else...
		require PICU_PATH . 'backend/includes/picu-email.php';

		// Everything that doesn't fit anywhere else...
		require PICU_PATH . 'backend/includes/picu-helper.php';

		// Handle ajax requests
		require PICU_PATH . 'backend/includes/picu-ajax.php';

		// Fix third party stuff
		require PICU_PATH . 'backend/includes/picu-opp.php';

		// Include template redirection etc. for collections
		require PICU_PATH . 'frontend/includes/picu-template-functions.php';

		// Load translations for Pro modules
		if ( version_compare( PHP_VERSION, '7.1.0' ) >= 0 ) {
			if ( ! function_exists( '\picu\Traduttore_Registry\add_project' ) ) {
				// Include traduttore registry
				require_once PICU_PATH . 'backend/includes/traduttore-registry.php';
			}

			// Get add-ons, that have registered with our hook earlier
			$picu_addons = array();
			$picu_addons = apply_filters( 'picu_addons', $picu_addons );

			foreach( $picu_addons as $picu_addon ) {
				if ( ! empty( $picu_addon['slug'] ) AND ! empty( $picu_addon['translations'] ) ) {
					// Enable translation downloads from translate.picu.io
					\picu\Traduttore_Registry\add_project(
						'plugin',
						$picu_addon['slug'],
						$picu_addon['translations']
					);
				}
			}
		}
	}
}

add_action( 'after_setup_theme', 'picu_setup' );


/**
 * Set transient to display welcome screen on activation
 *
 * @package picu
 * @since 0.7.0
 */

function picu_activate_welcome_screen() {
	// Set transient for redirect to activation screen
	set_transient( '_picu_welcome_screen_activation_redirect', true, 30 );
}

register_activation_hook( __FILE__, 'picu_activate_welcome_screen' );


/**
 * Flush rewrite rules on plugin activation/deactivation
 *
 * @since 0.7.0
 */
function picu_flush_rewrites() {

	// Include custom post type registration
	include( plugin_dir_path(__FILE__) . 'backend/includes/picu-cpt-collection.php' );

	// Make sure our custom post types are defined first
	picu_register_cpt_collection();

	// Flush the rewrite rules
	flush_rewrite_rules();

}

register_deactivation_hook( __FILE__, 'flush_rewrite_rules' );
register_activation_hook( __FILE__, 'picu_flush_rewrites' );


/**
 * Load language files to enable plugin translation
 *
 * @package picu
 * @since 0.1.0
 */

function picu_load_plugin_textdomain() {
	load_plugin_textdomain( 'picu', false, basename( dirname( __FILE__ ) ) . '/languages' );
}

add_action( 'plugins_loaded', 'picu_load_plugin_textdomain' );


/**
 * Load some custom styling for our admin screens
 *
 * @since 0.3.2
 */

function picu_admin_styles_scripts() {

	global $post;

	$current_screen = get_current_screen();

	// Prevent conflicts in case no current_screen is set
	if ( empty($current_screen) )
		return;

	// Only load those styles on edit collection screens
	if ( is_admin() ) {

		wp_enqueue_style( 'picu-admin', PICU_URL . 'backend/css/picu-admin.css', false, PICU_VERSION );

		global $pagenow;
		if ( $current_screen->post_type == 'picu_collection' AND get_post_type() == 'picu_collection' AND $pagenow == 'post-new.php' || $pagenow == 'post.php' ) {
			// Enqueue wp.media scripts manually, because we don't load the default editor on collections
			// Post needs to be provided, or uploaded media will not get attached to the collection
			$args = array( 'post' => $post->ID );
			wp_enqueue_media( $args );
		}

		if ( 'picu_page_picu-settings' == $current_screen->base ) {
			// Add the color picker css file
			wp_enqueue_style( 'wp-color-picker' );
		}

		if ( ( 'picu_collection' == $current_screen->post_type AND 'picu_collection' == get_post_type() AND 'post-new.php' == $pagenow || 'post.php' == $pagenow ) || ( 'picu_page_picu-settings' == $current_screen->base ) || ( 'picu_page_picu-add-ons' == $current_screen->base ) || ( 'dashboard_page_picu-welcome-screen' == $current_screen->base ) || ( 'picu_collection' == $current_screen->post_type AND 'picu_collection' == get_post_type() AND 'edit.php' == $pagenow ) ) {

			// Enqueue media
			wp_enqueue_media();

			// Register script
			wp_register_script( 'picu-admin', PICU_URL . 'backend/js/picu-admin.min.js', array( 'jquery', 'jquery-ui-draggable', 'jquery-ui-sortable', 'underscore', 'backbone', 'wp-color-picker' ), PICU_VERSION, true );

			$post_id = false;
			if ( isset( $post->ID ) AND ! empty( $post->ID ) ) {
				$post_id = $post->ID;
			}

			// Localize it
			$picu_localization_strings = array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'ajax_nonce' => wp_create_nonce( 'picu_ajax' ),
				'postID' => $post_id,
				'sent_option_label' => __( 'Sent', 'picu' ),
				'approved_option_label' => __( 'Approved', 'picu' ),
				'button_text_publish' => __( 'Publish', 'picu' ),
				'button_text_send_to_client' => __( 'Send to Client', 'picu' ),
			);

			$picu_localization_strings = apply_filters( 'picu_localization_strings', $picu_localization_strings );

			wp_localize_script( 'picu-admin', 'picu_admin', $picu_localization_strings );

			// Enqueue our custom script
			wp_enqueue_script( 'picu-admin' );
		}

	}

}

add_action( 'admin_enqueue_scripts', 'picu_admin_styles_scripts' );


/**
 * Add settings link in plugins overview
 *
 * @since 1.0.0
 */
function picu_plugin_action_links( $actions ) {

	$action = sprintf( '<a href="%s">%s</a>', admin_url( 'admin.php?page=picu-settings' ), __( 'Settings', 'picu' ) );
	array_unshift( $actions, $action );

	return $actions;
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , 'picu_plugin_action_links', 10 );


/**
 * Return capability that allows picu to be accessed
 *
 * Can be filtered using 'picu_capability'
 *
 * @since 1.1.0
 */
function picu_capability() {

	// Defaults to administrator privileges
	$picu_capability = 'manage_options';
	$picu_capability = apply_filters( 'picu_capability', $picu_capability );

	return $picu_capability;
}


/**
 * Redirect /picu to collection overview in WordPress admin
 *
 * @since 1.2.1
 */
function picu_redirect_to_overview() {
	if ( $_SERVER['REQUEST_URI'] == '/picu' OR $_SERVER['REQUEST_URI'] == '/picu/' ) {
		wp_redirect( admin_url() . 'edit.php?post_type=picu_collection' );
		exit;
	}
}

add_action( 'init', 'picu_redirect_to_overview' );


/**
 * Add picu Pro upgrade box
 */
function picu_add_pro_metabox() {

	// Get add-ons, that have registered with our hook earlier
	$picu_addons = array();
	$picu_addons = apply_filters( 'picu_addons', $picu_addons );

	if ( ! is_array( $picu_addons ) OR count( $picu_addons ) <= 0 ) {

		add_meta_box(
			'picu-pro-metabox',
			__( 'Get picu pro', 'picu' ),
			'picu_pro_metabox',
			'picu_collection',
			'side',
			'high'
		);
	}
}

add_action( 'add_meta_boxes', 'picu_add_pro_metabox' );


function picu_pro_metabox( $show_visibility_toggle = true ) {
	// Check if the current user has hidden the pro box
	$is_hidden = get_transient( 'picu_pro_box_hidden_' . get_current_user_id() );
?>
	<div class="picu-pro-meta-box">
		<div class="picu-pro-meta-box-intro">
			<span class="picu-pro-intro-claim"><?php _e( 'Get the most out of picu', 'picu' ); ?></span>
			<h2><a href="https://picu.io/pro/?utm_source=picu_plugin&utm_medium=pro_metabox" target="_blank"><?php _e( '<span>Upgrade to picu</span> <span class="picu-pro-pro">pro</span>', 'picu' ); ?></a></h2>
		</div>
		<?php
		if ( $show_visibility_toggle == true ) { ?>
		<input type="checkbox" id="picu-pro-meta-box-visibility" value="hidden"<?php if ( $is_hidden == true ) { echo ' checked'; } ?> />
		<label class="picu-pro-meta-box-visibility" for="picu-pro-meta-box-visibility"></label>
		<?php } ?>
		<div class="picu-pro-meta-box-content">
			<ul class="picu-pro-list">
				<li><?php _e( 'Add your personal branding to your collections', 'picu' ); ?></li>
				<li><?php _e( 'Comments and markers for individual images', 'picu' ); ?></li>
				<li><?php _e( 'Protect images with a watermark', 'picu' ); ?></li>
				<li><?php _e( 'Set selection goals: Define how many images your client needs to approve', 'picu' ); ?></li>
				<li><?php _e( 'Upload via FTP and import images directly from your webserver', 'picu' ); ?></li>
				<li><?php _e( 'Enable clients to download all images as a .zip file', 'picu' ); ?></li>
				<li><?php _e( 'Priority support', 'picu' ); ?></li>
				<li><?php _e( 'Hide this box!', 'picu' ); ?></li>
			</ul>
			<p class="picu-pro-button-wrap"><a class="button button-primary" href="https://picu.io/pro/?utm_source=picu_plugin&utm_medium=pro_metabox"  target="_blank"><?php _e( 'Get picu Pro now', 'picu' ); ?></a></p>
		</div>
	</div>
<?php
}


/**
 * Hide admin bar for now
 */
add_filter( 'picu_show_admin_bar', '__return_false' );


/**
 * Check if collection slug has changed
 * 
 * @since 1.5.0
 */
function picu_check_collection_slug() {

	// Only run if collection or 404
	if ( 'picu_collection' != get_post_type() AND ! is_404() ) {
		return;
	}

	// Only run, if pretty permalinks are active
	if ( ! get_option( 'permalink_structure' ) ) {
		return;
	}

	// Get current collection slug
	$post_type = get_post_type_object( 'picu_collection' );
	$post_type_slug = $post_type->rewrite['slug'];

	// Get saved slug. Set, if empty
	$saved_slug = get_transient( 'picu_collection_slug' );

	if ( empty( $saved_slug ) ) {
		set_transient( 'picu_collection_slug', $post_type_slug, 0 );
		return;
	}
	
	// Compare current with saved collection slug
	if ( $post_type_slug != $saved_slug ) {
		$old_picu_slugs = get_transient( 'picu_collection_old_slugs' );
		$old_picu_slugs[] = $saved_slug;
		set_transient( 'picu_collection_old_slugs', array_unique( $old_picu_slugs ) );
		set_transient( 'picu_collection_slug', $post_type_slug, 0 );
		flush_rewrite_rules( false );
	}
}

add_action( 'wp', 'picu_check_collection_slug' );


/**
 * Redirect when old collection base slug is used
 * 
 * @since 1.5.0
 */
function picu_redirect_from_old_slug( $query ) {

	// Only run, if this is a 404
	if ( ! is_404() ) {
		return;
	}

	// Only run, if pretty permalinks are active
	if ( ! get_option( 'permalink_structure' ) ) {
		return;
	}

	// Check if the old slug transient is set
	$old_picu_slugs = get_transient( 'picu_collection_old_slugs' );

	if ( empty( $old_picu_slugs ) ) {
		return;
	}

	// Get current url & path
	global $wp;
	$current_url = home_url( $wp->request );
	$url = parse_url( $current_url );
	$path = explode( '/', $url['path'] );

	// Get current picu collection slug
	$post_type_object = get_post_type_object( 'picu_collection' );
	$current_slug = $post_type_object->rewrite['slug'];

	if ( empty( $path[1] ) OR ! in_array( $path[1], $old_picu_slugs ) OR $path[1] == $current_slug ) {
		return;
	}
	
	// Replace old slug with the new one
	$new_url = $url['scheme'] . '://' . $url['host'] . '/' . $current_slug . '/' . $path[2] . '/';

	// Get post type by url for the collection
	$post_type = get_post_type( url_to_postid( $new_url ) );

	// Redirect if the url is actually a collection
	if ( 'picu_collection' == $post_type ) {
		wp_redirect( trailingslashit( $new_url ), 301 );
	}
}

add_filter( 'wp', 'picu_redirect_from_old_slug' );